==> xtuple-4.5.0-dev4.tgz: package/lib/enyo-x/source/en/strings.js <==
/*jshint node:true, indent:2, curly:false, eqeqeq:true, immed:true,
latedef:true, newcap:true, noarg:true, regexp:true, undef:true,
strict:true, trailing:true, white:true */
/*global XT:true */

// Place strings you want to localize here.  In your app, use the key and
// localize it using "key string".loc().  HINT: For your key names, use the
// english string with an underscore in front.  This way you can still see
// how your UI will look and you'll notice right away when something needs a
// localized string added to this file!

(function () {
  "use strict";

  var lang = XT.stringsFor("en_US", {
    "_about": "About",
    "_accountParent": "Account Parent",
    "_actions": "Actions",
    "_advancedSearch": "Advanced Search",
    "_addChart": "Add Chart",
    "_always": "Always",
    "_any": "Any",
    "_apply": "Apply",
    "_attr": "Attr",
    "_back": "Back",
    "_cancel": "Cancel",
    "_changePassword": "Change Password",
    "_child": "Child",
    "_childOf": "Child of",
    "_chooseOne": "Choose One",
    "_city": "City",
    "_column": "Column",
    "_changeLayout": "Change Layout",
    "_comments": "Comments",
    "_characteristics": "Characteristics",
    "_country": "Country",
    "_currentLayout": "Current Layout",
    "_dashboard": "Dashboard",
    "_delete": "Delete",
    "_discard": "Discard",
    "_documents": "Documents",
    "_done": "Done",
    "_download": "Download",
    "_duplicate": "Duplicate",
    "_duplicateOf": "Duplicate of",
    "_edit": "Edit",
    "_editAddress": "Edit Address",
    "_expand": "Expand",
    "_export": "Export",
    "_field": "Field",
    "_filter": "Filter",
    "_filters": "Filters",
    "_filterOn": "Filter On",
    "_filterName": "Filter Name",
    "_groupBy": "Group By",
    "_help": "Help",
    "_hide": "Hide",
    "_history" : "History",
    "_isShared": "Shared",
    "_issueDate": "Issue Date",
    "_issueSelected": "Issue All Selected",
    "_issueSelectedStock": "Issue Quantity for Selected",
    "_layout": "Layout",
    "_layoutName": "Layout Name",
    "_less": "Less Options",
    "_loading": "Loading",
    "_manage": "Manage",
    "_manageFilters": "Manage Filters",
    "_manageLayouts": "Manage Layouts",
    "_map": "Map",
    "_more": "More Options",
    "_myAccount": "My Account",
    "_new": "New",
    "_never": "Never",
    "_next": "Next",
    "_no": "No",
    "_none": "None",
    "_ok": "Ok",
    "_oldPassword": "Old Password",
    "_open": "Open",
    "_openNewTab": "New Tab",
    "_overview": "Overview",
    "_parameters": "Parameters",
    "_parent": "Parent",
    "_parentOf": "Parent of",
    "_passwordMismatch": "Passwords don't match",
    "_post": "Post",
    "_postalCode": "Postal Code",
    "_preferences": "Preferences",
    "_previous": "Previous",
    "_print": "Print",
    "_printList": "Print List",
    "_printSelect": "Print Selected",
    "_processing": "Processing",
    "_purpose": "Purpose",
    "_refresh": "Refresh",
    "_related": "Related",
    "_relatedTo": "Related to",
    "_report": "Report",
    "_reportList": "Report List",
    "_requireSufficientInventory": "Require Sufficient Inventory",
    "_returnSelected": "Return All Selected",
    "_removeChart": "Remove Chart",
    "_row": "Row",
    "_save": "Save",
    "_saveAndNew": "Save and New",
    "_saveLayout": "Save Layout",
    "_saving": "Saving",
    "_saveFilter": "Save Filter",
    "_savedFilters": "Saved Filters",
    "_search": "Search",
    "_sort": "Sort",
    "_sortBy": "Sort By...",
    "_street": "Street",
    "_state": "State",
    "_then": "Then...",
    "_yes": "Yes",

    // ********
    // Messages
    // ********
    "_confirmAction": "Are you sure this is what you want to do?",
    "_changeAll": "Change All",
    "_changeOne": "Change only this one",
    "_confirmDelete": "This will permanently delete this record.",
    "_editFilter?": "Do you want to edit this filter?",
    "_filterExists": "A filter exists with this name.",
    "_invalidPassword": "Entry does not match your old password. Please re-enter.",
    "_insufficientCreatePrivileges": "You do not have sufficient privileges to create this record.",
    "_insufficientViewPrivileges": "You do not have sufficient privileges to view this record.",
    "_loadingApplicationData": "Loading Application Data",
    "_loadingExtensions": "Loading Extensions",
    "_loadingSchema": "Loading Schema",
    "_loadingSessionData": "Loading Session Data",
    "_lockInfo": "This record has been locked by {user} since {effective}.",
    "_logoutConfirmation": "Are you sure you want to log out?",
    "_openAdvancedWorkspace": "Open Advanced Workspace",
    "_newPassword": "New Password",
    "_noDescription": "No Description",
    "_noDocumentFound": "No Document Found.",
    "_noEligibleActions": "No Eligible Actions",
    "_noOldPassword": "Please enter your old password",
    "_unsavedChanges": "You have unsaved changes.",
    "_saveYourWork?": "Do you want to save your work?"
  });

  if (typeof exports !== 'undefined') {
    exports.language = lang;
  }
}());

==> xtuple-4.8.0.tgz: package/lib/enyo-x/source/en/strings.js <==
/*jshint node:true, indent:2, curly:false, eqeqeq:true, immed:true,
latedef:true, newcap:true, noarg:true, regexp:true, undef:true,
strict:true, trailing:true, white:true */
/*global XT:true */

// Place strings you want to localize here.  In your app, use the key and
// localize it using "key string".loc().  HINT: For your key names, use the
// english string with an underscore in front.  This way you can still see
// how your UI will look and you'll notice right away when something needs a
// localized string added to this file!

(function () {
  "use strict";

  var lang = XT.stringsFor("en_US", {
    "_about": "About",
    "_accountParent": "Account Parent",
    "_actions": "Actions",
    "_advancedSearch": "Advanced Search",
    "_addChart": "Add Chart",
    "_always": "Always",
    "_any": "Any",
    "_apply": "Apply",
    "_attr": "Attr",
    "_back": "Back",
    "_cancel": "Cancel",
    "_changePassword": "Change Password",
    "_child": "Child",
    "_childOf": "Child of",
    "_chooseOne": "Choose One",
    "_city": "City",
    "_column": "Column",
    "_changeLayout": "Change Layout",
    "_comments": "Comments",
    "_characteristics": "Characteristics",
    "_country": "Country",
    "_cust#": "Cust #",
    "_currentLayout": "Current Layout",
    "_dashboard": "Dashboard",
    "_dashboardLite": "Dashboard Lite",
    "_delete": "Delete",
    "_discard": "Discard",
    "_documents": "Documents",
    "_done": "Done",
    "_download": "Download",
    "_duplicate": "Duplicate",
    "_duplicateOf": "Duplicate of",
    "_edit": "Edit",
    "_editAddress": "Edit Address",
    "_expand": "Expand",
    "_export": "Export",
    "_field": "Field",
    "_filter": "Filter",
    "_filters": "Filters",
    "_filterOn": "Filter On",
    "_filterName": "Filter Name",
    "_groupBy": "Group By",
    "_help": "Help",
    "_hide": "Hide",
    "_history" : "History",
    "_isShared": "Shared",
    "_issueDate": "Issue Date",
    "_issueSelected": "Issue All Selected",
    "_issueSelectedStock": "Issue Quantity for Selected",
    "_layout": "Layout",
    "_layoutName": "Layout Name",
    "_less": "Less Options",
    "_loading": "Loading",
    "_manage": "Manage",
    "_manageFilters": "Manage Filters",
    "_manageLayouts": "Manage Layouts",
    "_map": "Map",
    "_more": "More Options",
    "_myAccount": "My Account",
    "_new": "New",
    "_never": "Never",
    "_next": "Next",
    "_no": "No",
    "_none": "None",
    "_ok": "Ok",
    "_oldPassword": "Old Password",
    "_open": "Open",
    "_openNewTab": "New Tab",
    "_ord#": "Ord #",
    "_overview": "Overview",
    "_parameters": "Parameters",
    "_parent": "Parent",
    "_parentOf": "Parent of",
    "_passwordMismatch": "Passwords don't match",
    "_post": "Post",
    "_postalCode": "Postal Code",
    "_preferences": "Preferences",
    "_previous": "Previous",
    "_print": "Print",
    "_printList": "Print List",
    "_printSelect": "Print Selected",
    "_processing": "Processing",
    "_purpose": "Purpose",
    "_refresh": "Refresh",
    "_related": "Related",
    "_relatedTo": "Related to",
    "_report": "Report",
    "_reportList": "Report List",
    "_requireSufficientInventory": "Require Sufficient Inventory",
    "_returnSelected": "Return All Selected",
    "_removeChart": "Remove Chart",
    "_row": "Row",
    "_save": "Save",
    "_saveAndNew": "Save and New",
    "_saveLayout": "Save Layout",
    "_saving": "Saving",
    "_saveFilter": "Save Filter",
    "_savedFilters": "Saved Filters",
    "_scheddate": "Sched Date",
    "_search": "Search",
    "_sort": "Sort",
    "_sortBy": "Sort By...",
    "_street": "Street",
    "_state": "State",
    "_then": "Then...",
    "_yes": "Yes",

    // ********
    // Messages
    // ********
    "_confirmAction": "Are you sure this is what you want to do?",
    "_changeAll": "Change All",
    "_changeOne": "Change only this one",
    "_confirmDelete": "This will permanently delete this record.",
    "_editFilter?": "Do you want to edit this filter?",
    "_filterExists": "A filter exists with this name.",
    "_invalidPassword": "Entry does not match your old password. Please re-enter.",
    "_insufficientCreatePrivileges": "You do not have sufficient privileges to create this record.",
    "_insufficientViewPrivileges": "You do not have sufficient privileges to view this record.",
    "_loadingApplicationData": "Loading Application Data",
    "_loadingExtensions": "Loading Extensions",
    "_loadingSchema": "Loading Schema",
    "_loadingSessionData": "Loading Session Data",
    "_lockInfo": "This record has been locked by {user} since {effective}.",
    "_logoutConfirmation": "Are you sure you want to log out?",
    "_openAdvancedWorkspace": "Open Advanced Workspace",
    "_newPassword": "New Password",
    "_noDescription": "No Description",
    "_noDocumentFound": "No Document Found.",
    "_noEligibleActions": "No Eligible Actions",
    "_noItemFound": "No item found",
    "_noOldPassword": "Please enter your old password",
    "_unsavedChanges": "You have unsaved changes.",
    "_saveYourWork?": "Do you want to save your work?"
  });

  if (typeof exports !== 'undefined') {
    exports.language = lang;
  }
}());
